@@ -180,7 +180,9 @@ class ITerm2Image(GraphicsImage, metaclass=ITerm2ImageMeta):
 
     * **method** (*None | str*) → Render method override.
 
-      * ``None`` → the current effective render method of the instance is used.
+      * ``None`` → the current effective render method of the instance is used
+      * A valid render method name (as specified in the **Render Methods** section
+        above) → used instead of the current effective render method of the instance
       * *default* → ``None``
 
     * **mix** (*bool*) → Cell content inter-mix policy (**Only supported on WezTerm**,
